@@ -1,4 +1,4 @@
-print.fmres = function (x, ...) 
+print.fmres <- function(x, ...) 
 {
     if (class(x)[1] == "fmres") {
         cat("Residuals of a functional model\n")
@@ -10,4 +10,4 @@ print.fmres = function (x, ...)
     else {
         stop("object is not a functional time series model")
     }
-}
\ No newline at end of file
+}
